@@ -21,7 +21,8 @@
 #' @export
 #'
 report_plots <- function(df, dist) {
-    D_p = microns = sys_eff = probs = ambient = bin_eff = sampled = . = starts_with = everything = element = efficiency = amb_mass = rel_activity = location = NULL
+    D_p = microns = sys_eff = dens = ambient = bin_eff = sampled = . = starts_with = everything = element = efficiency = amb_mass = rel_activity = location = NULL
+
     eff_cols <- tidyselect::starts_with("eff_", vars = names(df))
 
     if (dist == "discrete") {
@@ -56,16 +57,18 @@ report_plots <- function(df, dist) {
       df_log$bin_eff <- apply(df_log[, eff_cols], 1, prod)
       # compute ambient mass-based quantity for each bin
 
-      df_log$ambient <- df_log$probs * 4/3 *
-        pi * (df_log$D_p/2)^3
+      df_log$ambient <- df_log$dens * 4/3 *
+        pi * (df_log$D_p/2)^3 * diff(c(0, df_log$D_p))
 
       df_log$sampled <- df_log$ambient * df_log$bin_eff
 
       df_log$microns <-  df_log$D_p
       df_log |> dplyr::select(microns, ambient, sampled) |>
-            tidyr::pivot_longer(2:3, names_to = "location", values_to = "rel_activity") |>
-            ggplot2::ggplot(ggplot2::aes(microns, rel_activity, color = location)) +
-            ggplot2::geom_point() + ggplot2::ggtitle("ambient and sampled activity")
+            tidyr::pivot_longer(2:3, names_to = "location",
+                                values_to = "rel_activity") |>
+
+      ggplot2::ggplot(ggplot2::aes(microns, rel_activity, color = location)) +
+      ggplot2::geom_point() + ggplot2::ggtitle("ambient and sampled activity")
     }
 
 }
